@@ -8,26 +8,28 @@ test_that("create_range_plot()", {
   expect_snapshot({
     a_plot <- RplotterPkg::create_range_plot(
       df = RplotterPkg::penguins_stats,
-      orientation = "x",
-      aes_x = "avg_body_mass",
-      aes_y = "species",
-      aes_min = "min_body_mass",
-      aes_max = "max_body_mass",
+      orientation = "horizontal",
+      factor_var = "species",
+      min_meas = "min_body_mass",
+      max_meas = "max_body_mass",
+      labels_meas = "avg_body_mass",
+      labels = "mid_labels",
+      labels_fill = "yellow",
       title = "Average and Range of Penguins Body Mass(g) by Species",
       subtitle = "Source: palmerpenguins",
       center_titles = TRUE,
-      x_title = "Body Mass(g)",
-      y_title = "Species",
-      pts_fill = "blue",
-      pts_shape = 22,
-      pts_stroke = 1.7,
+      factor_title = "Species",
+      meas_title = "Body Mass(g)",
+      pts_fill = c("white", "red"),
       pts_size = 3,
+      pts_shape = 21,
+      pts_stroke = 1,
       line_width = 1.5,
       line_type = "solid",
-      line_pts_color = "red",
       line_pts_alpha = 0.5,
-      x_limits = c(2500, 7000),
-      x_major_breaks = seq(2500,7000,500),
+      meas_limits = c(2500, 7000),
+      meas_major_breaks = seq(2500,7000,500),
+      rot_y_tic_label = TRUE,
       show_major_grids = TRUE,
       show_minor_grids = FALSE
     )
